@@ -76,6 +76,12 @@ _registry = {
             "cloud_dsapi": ['lists', 'get_by_id', 'create', 'update', 'delete', 'search'],
             "cloud_context": ['get_by_id', 'create', 'update', 'delete', 'search']
         },
+    "models":
+        {
+            "class": ModelInfo,
+            "cloud_dsapi": ['download_model', 'download_file' , 'upload_model'  , 'upload_file'],
+            "cloud_context": ['download_model' , 'download_file' , 'upload_model'  , 'upload_file']
+        },
     "pipelines":
         {
             "class": Pipeline,
