@@ -29,7 +29,7 @@ class ModelIdentifierInfo:
         return obj
 
     def from_json(self, json_dict):
-        if "active_alias" in json_dict:
+        if "active_alias" in json_dict and json_dict["active_alias"] is not None:
             self.active_alias = json_dict["active_alias"]
 
 class ModelFile:
@@ -133,7 +133,8 @@ class ModelInfo:
                  trained_model = None,
                  scaler = None,
                  files = None,
-                 updated_date = None
+                 updated_date = None,
+                 metadata: dict = None
                  ):
         # information identifying a model
         self.key = key
@@ -153,7 +154,8 @@ class ModelInfo:
                 if not isinstance(file, ModelFile):
                     raise TypeError("file is not a ModelFile with files")
         self.is_active = False
-        self.updated_date = None
+        self.updated_date = updated_date
+        self.metadata = metadata
 
         # files attached to model when loaded
         self.trained_model = trained_model
@@ -264,6 +266,8 @@ class ModelInfo:
             obj["files"] = [file.to_json() for file in self.files]
         if self.updated_date is not None:
             obj["updatedDate"] = str(self.updated_date)
+        if self.metadata is not None:
+            obj["metadata"] = self.metadata
         return obj
 
     def from_json(self, obj):
@@ -290,6 +294,8 @@ class ModelInfo:
             self.is_active = get_bool(obj, name="is_active")
         if "updatedDate" in obj.keys() and obj["updatedDate"] is not None:
             self.updated_date = obj["updatedDate"]
+        if "metadata" in obj.keys() and obj["metadata"] is not None:
+            self.metadata = obj["metadata"]
         if "files" in obj.keys():
             for obj_file in obj["files"]:
                 model_file = ModelFile()
@@ -304,6 +310,17 @@ class ModelInfo:
             raise RuntimeError("api is not bound to the dto use bind_api()")
         self._api.load_model(self)
 
+    def uncompress_bytes_to_model(self, bytes_model):
+        import io, joblib
+        if self.file_format == "pkl":
+            self.trained_model = joblib.load(io.BytesIO(bytes_model))
+        elif self.file_format == "pt":
+            import torch
+            buffer = io.BytesIO(bytes_model)
+            self.trained_model = torch.jit.load(buffer)
+        else:
+            raise RuntimeError(f'unsupported file format {self.file_format} must be pt or pkl')
+
 
 class ModelList:
     """
@@ -355,6 +372,21 @@ class ModelList:
         else:
             raise TypeError("ModelList indices must be int, str or ModelInfo.")
 
+    def select_all_active_model(self) -> list[ModelInfo]:
+        """
+        select all active model for all possible identifier.
+        :return: return a list of ModelInfo only with active models.
+        """
+        distinct_identifiers = []
+        for model in self.models:
+            identifier = model.identifier(include_alias=False)
+            if identifier not in distinct_identifiers:
+                distinct_identifiers.append(identifier)
+        models = []
+        for identifier in distinct_identifiers:
+            models.append(self.select_active_model(identifier=identifier))
+        return models
+
     def select_active_model(self, identifier: str) -> ModelInfo:
         """
         return the active model based on active status or latest one if none active.
@@ -368,7 +400,7 @@ class ModelList:
                     return model
                 else:
                     models.append(model)
-        return max(models, key=lambda f: f.updated_date, default=None)
+        return max(models, key=lambda f: f.updated_date or 0, default=None)
 
     def append(self, model: ModelInfo):
         self.models.append(model)
