@@ -1,5 +1,6 @@
 import uuid
 import json
+import sys
 
 import pandas
 import wizata_dsapi
@@ -159,13 +160,13 @@ class PipelineIO(ApiDto):
             obj["columns"] = self.columns
         return obj
 
-    def prepare(self, df: pandas.DataFrame) -> pandas.DataFrame:
+    def _prepare_df(self, df: pandas.DataFrame) -> pandas.DataFrame:
         """
-        prepare the dataframe based in information from this pipeline I/O definition.
-        perform mapping, selection and drops.
+        prepare dataframe in both 3.9 and 3.11+
         :param pandas.DataFrame df: dataframe to prepare.
         :return: prepared dataframe.
         """
+
         try:
             prepare_df = df.copy()
 
@@ -186,6 +187,25 @@ class PipelineIO(ApiDto):
         except Exception as e:
             raise RuntimeError(f'not able to prepare your dataframe following Pipeline I/O directives {e}')
 
+    if sys.version_info >= (3, 11):
+
+        ## with torch support
+        import torch
+        from typing import Union
+
+        def prepare(self, df: Union[pandas.DataFrame, torch.Tensor]) -> Union[pandas.DataFrame, torch.Tensor]:
+            import torch
+            if isinstance(df, torch.Tensor):
+                return df
+            else:
+                return self._prepare_df(df)
+
+    else:
+
+        ## without torch support
+        def prepare(self, df: pandas.DataFrame) -> pandas.DataFrame:
+            return self._prepare_df(df)
+
     @classmethod
     def from_obj(cls, obj):
         """
