@@ -1,9 +1,9 @@
 import json
-
+import os
+import wizata_dsapi
 from .api_dto import ApiDto
 from .pipeline import Pipeline
 from .script import Script
-from .mlmodel import ModelInfo
 from datetime import datetime
 
 import pytz
@@ -11,7 +11,6 @@ import io
 import tarfile
 import gzip
 import dill
-import pickle
 
 
 def files_from_gzipped_data(gzipped_data):
@@ -153,7 +152,29 @@ class PipelineImage(ApiDto):
             # process the models
             model_files = {k: v for k, v in g_files.items() if k.startswith('models/')}
             for pkl_file in model_files:
-                image.models[pkl_file[7:-4]] = pickle.loads(g_files[pkl_file])
+                parts = pkl_file.split('/')
+                if len(parts) == 2:
+                    identifier = os.path.splitext(parts[1])[0]
+                else:
+                    identifier = parts[1]
+
+                if identifier not in image.models:
+                    key, twin_hardware_id, property_value, alias = wizata_dsapi.ModelInfo.split_identifier(identifier)
+                    image.models[identifier] = wizata_dsapi.ModelInfo(
+                        key=key,
+                        twin_hardware_id=twin_hardware_id,
+                        property_value=property_value,
+                        alias=alias
+                    )
+                if len(parts) == 2:
+                    image.models[identifier].file_format = os.path.splitext(parts[1])[1].lstrip('.')
+                    image.models[identifier].uncompress_bytes_to_model(g_files[pkl_file])
+                if len(parts) == 3:
+                    image.models[identifier].add_file(wizata_dsapi.ModelFile(
+                        full_path=pkl_file,
+                        path=parts[2],
+                        content=g_files[pkl_file]
+                    ))
 
             return image
 
