@@ -1142,10 +1142,16 @@ class WizataDSAPIClient(ApiInterface, ApiDtoInterface):
             for file in model_info.files:
                 file: wizata_dsapi.ModelFile
                 if file.name != "trained_model":
-                    headers["Content-Type"] = "application/octet-stream"
+                    single_file = {
+                        "file": (
+                            file.path,
+                            file.content,
+                            "application/octet-stream",
+                        )
+                    }
                     response = requests.post(self.__url() + f"models/{model_info.identifier(include_alias=True)}/files/{file.path}",
                                              headers=headers,
-                                             data=file.content,
+                                             files=single_file,
                                              timeout=60)
                     if response.status_code != 200 and response.status_code != 201:
                         raise self.__raise_error(response)
@@ -2021,10 +2027,17 @@ class WizataDSAPIClient(ApiInterface, ApiDtoInterface):
             path = file.path
 
         headers = self.__header()
-        headers["Content-Type"] = "application/octet-stream"
+        headers.pop("Content-Type", None)
+        single_file = {
+            "file": (
+                path,
+                content,
+                "application/octet-stream",
+            )
+        }
         response = requests.post(self.__url() + f"models/{identifier}/files/{path}",
                                  headers=headers,
-                                 data=content,
+                                 files=single_file,
                                  timeout=60)
         if response.status_code != 200 and response.status_code != 201:
             return
